#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::OS::solaris - Solaris specific configuration information
#
package Security::OS::solaris;

use Exporter;
use POSIX;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( init check );

sub init {
	print ( STDERR  "In Security::OS::solaris::init()\n") if ( $main::opts{'d'} );

	$main::showmount = '/usr/sbin/showmount';
	$main::exportsfile = '/etc/dfs/dfstab';
	$main::kerneldir = '/kernel/drv';
	$main::kernelmodlist = '/usr/sbin/modinfo | awk \'NR > 1 {print $6}\'';
	$main::loginfile='/etc/default/login';
	$main::sudofile = '/etc/sudoers';
	$main::sudofile = '/usr/local/etc/sudoers'
		if ( -f '/usr/local/etc/sudoers' );
	$main::binuid = 2;
	$main::login_length = POSIX::sysconf( 571 );
}

sub check {
	print ( STDERR  "In Security::OS::solaris::check()\n") if ( $main::opts{'d'} );

	&Security::rootlogin::check_defaultlogin() 
		if ( defined &Security::rootlogin::check_defaultlogin );
}

1;

__END__

=head1 NAME

Security::OS::solaris

=head1 SYNOPSIS

Security::OS::solaris::init();

Security::OS::solaris::check();

=head1 DESCRIPTION

Sets variables for OS specific commands.

=head1 API

Defines the following API calls

=over 4

=item C<init()>

Init sets the following global variables:

=over 4

=item C<$main::showmount>

The location of the showmount command, used in the C<Security::exports> module.

=item C<$main::exportsfile>

The location of the exports file, used in C<Security::exports> module.

=item C<$main::sudofile>

The location of F<sudoers> file, used in C<Security::sudo> module.

=item C<$main::kerneldir>

The location of the kernel loadable modules, used in C<Security::kernel>
module.

=item C<$main::loginfile>

The location of the list of ports root is allowed in on, used in
C<Security::rootlogin> module.

=back

=item C<check()>

Calls C<Security::rootlogin::check_defaultlogin()> to check what root ports
are configured and compares it to what ports we know about.

=back

=cut

