#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::die - Custom die routine
#
package Security::util::die;

use Exporter;
use Security::util::print;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT = qw( security_die );

# Replacement function for the die perl call, if the email address option
# is set, write to that instead of STDERR.
sub security_die {
	my ($msg) = @_;

	# Possibly set the output device ($opts{'M'})
	&Security::util::print::check_fp();
	if ( $main::opts{'M'} eq '-' ) {
		die $msg;
	} else {
		&print_header($msg);
	}
	&print_close();
	exit 1;
}

1;

__END__

=head1 NAME

Security::util::die - Custom die routine

=head1 SYNOPSIS

use Security::util::die;

open ($FP, ...) || &security_die("Could not open file\n");

=head1 DESCRIPTION

Depending on the output device, will write the die message to the
file, SMTP server or screen.

=head1 method

It provides the following method for other modules to use.

=over 4

=item C<security_die($msg)>

Will write C<$msg> to the SMTP server, file or calls die() directly,
depending on what C<$main::opts{'M'}> is set to.

=back

=head1 SEE ALSO

L<die>

=cut
