#!/usr/bin/env perl
#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  07.t - user config file testing.
#

use Test;
use strict;
use warnings "all";

use t::common;

plan tests => 6;

use Security::util::users;
use Security::user;

our (%opts, %config);
#$opts{'d'} = 1;

# Use this test script as an intruder file test.
@{$config{'userfiles'}} = (
	'security_test.' . $$,
	'security_test.' . $$ . '.2',
	'security_test.' . $$ . '.3',
	'security_test.' . $$ . '.4:0400',
	'security_test.' . $$ . '.5:0600',
);

sub print_data {}

&Security::util::users::init();
&Security::user::init();

# Create files we should complain about
&create_file("$ENV{'HOME'}/$config{'userfiles'}[0]", -1, -1, 0646);		# Complain about file other modes
&create_file("$ENV{'HOME'}/$config{'userfiles'}[1]", $<+1, -1, 0600);		# Complain about file ownership
&create_file("$ENV{'HOME'}/$config{'userfiles'}[2]", -1, -1, 0660);		# Complain about file group modes
my ($f) = $ENV{'HOME'} . '/' . $config{'userfiles'}[3];
$f =~ s/:\d+$//;
&create_file($f, -1, -1, 0640);		# Complain about file modes
my ($f2) = $ENV{'HOME'} . '/' . $config{'userfiles'}[4];
$f2 =~ s/:\d+$//;
&create_file($f2, -1, -1, 0600);		# Do not complain about file modes

&Security::user::check();

ok ( scalar keys %Security::user::perms>=2, 1, "Did not find the correct number of user config errors");
ok ( $Security::user::perms{"$ENV{'HOME'}/$config{'userfiles'}[0]"}, 'world writable', "Found not right number of world writable config files");
skip (
	($< != 0? "Test needs to be run as root": 0),
	$Security::user::perms{"$ENV{'HOME'}/$config{'userfiles'}[1]"}, "owner (" . $<. ":" . ($<+1) . ")",
);
ok ( $Security::user::perms{"$ENV{'HOME'}/$config{'userfiles'}[2]"}, 'group writable', "Found not right number of group writable config files");
ok ( $Security::user::perms{$f}, 'mode (0400:0640)', "Did not find the file mode error");
ok ( $Security::user::perms{$f2}, undef, "Found an error we should not have");

unlink(@t::common::FILES);

exit 0;
