#!/usr/bin/env perl
#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  12.t - sudo module testing
#

use Test;
use strict;
use warnings "all";

use Security::sudo;
use Security::db;
use Security::util::SHA1;
use Security::util::groups;
use Security::util::users;

plan tests => 11;

our (%opts, %config, $sudofile, $binuid);
#$opts{'d'} = 1;

# Setup defaults
#@{$config{'nosudoowner'}} = 'no';
$sudofile = 't/sudoers';
$binuid = 2;
my $me = getlogin();

# write out our test sudoers file:
my $FP;
my $sudo = "
Defaults	syslog=authpriv
Defaults	requiretty
Defaults	env_reset

Defaults	env_keep = \"PATH HOSTNAME EDITOR VISUAL DISPLAY\"

# The default entry we should just ignore
%wheel ALL=(ALL) ALL

nobody localhost=($me)NOPASSWD:./sbin/security.pl
$me localhost=(root)NOPASSWD:./sbin/checksum-dump.pl

# different layout we should parse properly
$me localhost = (root) ./sbin/generate_config.pl, /bin/cp, /bin/mv

# A non existant command we should detect
$me localhost = (root) /bin/foo

# A world writable command we should also detect
$me localhost = (root) ./t/test
";
open ($FP, ">$sudofile") || die "Could not write out test t/sudoers file\n";
print $FP $sudo;
close $FP;
`touch t/test`;
`chmod 777 t/test`;

&Security::util::SHA1::init();
&Security::util::users::init();
&Security::util::groups::init();
&Security::sudo::check();

# Make sure we found all the bad root accounts
ok ( scalar keys %Security::sudo::sudoowner, 3, "Could not find the correct number of bad comamnds");
ok ( $Security::sudo::sudoowner{'./sbin/security.pl'}, undef, "Found a bad command (that we should not have found)");
ok ( $Security::sudo::sudoowner{'./sbin/checksum-dump.pl'}, 1, "Did not find the bad comamnd");
ok ( $Security::sudo::sudoowner{'./sbin/generate_config.pl'}, 1, "Did not find the bad comamnd");
ok ( $Security::sudo::sudoowner{'./t/test'}, 1, "Did not find the bad comamnd");

ok ( scalar keys %Security::sudo::sudomissing, 1, "Could not find the correct number of missing comamnds");
ok ( $Security::sudo::sudomissing{'/bin/cp'}, undef, "Found a missing command (that we should not have found)");
ok ( $Security::sudo::sudomissing{'/bin/foo'}, 1, "Did not find the missing command");

ok ( scalar keys %Security::sudo::sudoworld, 1, "Could not find the correct number world writable comamnds");
ok ( $Security::sudo::sudoworld{'/bin/mv'}, undef, "Found a world writable command (that we should not have found)");
ok ( $Security::sudo::sudoworld{'./t/test'}, 1, "Did not find the world writable command");

unlink ($sudofile, './t/test' );

exit 0;
